var NAVTREEINDEX0 =
{
"annotated.html":[5,0],
"classes.html":[5,1],
"dir_68267d1309a1af8e8297ef4c3efbcdba.html":[6,0,0],
"files.html":[6,0],
"functions.html":[5,2,0],
"functions_vars.html":[5,2,1],
"globals.html":[6,1,0,0],
"globals.html":[6,1,0],
"globals_b.html":[6,1,0,1],
"globals_c.html":[6,1,0,2],
"globals_d.html":[6,1,0,3],
"globals_defs.html":[6,1,6],
"globals_e.html":[6,1,0,4],
"globals_enum.html":[6,1,4],
"globals_eval.html":[6,1,5],
"globals_f.html":[6,1,0,5],
"globals_func.html":[6,1,1],
"globals_g.html":[6,1,0,6],
"globals_h.html":[6,1,0,7],
"globals_i.html":[6,1,0,8],
"globals_j.html":[6,1,0,9],
"globals_l.html":[6,1,0,10],
"globals_m.html":[6,1,0,11],
"globals_n.html":[6,1,0,12],
"globals_o.html":[6,1,0,13],
"globals_p.html":[6,1,0,14],
"globals_r.html":[6,1,0,15],
"globals_s.html":[6,1,0,16],
"globals_t.html":[6,1,0,17],
"globals_type.html":[6,1,3],
"globals_u.html":[6,1,0,18],
"globals_v.html":[6,1,0,19],
"globals_vars.html":[6,1,2],
"globals_w.html":[6,1,0,20],
"globals_x.html":[6,1,0,21],
"hangul_8h.html":[6,0,0,0],
"hangul_8h.html#a00c77dd9a1bd92e8238ceb3fd9851d40":[6,0,0,0,39],
"hangul_8h.html#a0144f1668fd31e4caaa307236fdcd24a":[6,0,0,0,35],
"hangul_8h.html#a056fdfdb02eeccd48026c05ccb200435":[6,0,0,0,61],
"hangul_8h.html#a069b03f528213c0d14b78e5d4d61eccc":[6,0,0,0,60],
"hangul_8h.html#a0701ea8bfe17f2b3360397b3fa8dad05":[6,0,0,0,8],
"hangul_8h.html#a072e34c7730814b97335b6b59b69eb41":[6,0,0,0,23],
"hangul_8h.html#a07b8c0163dd9e9b6f2560f09e0f3e570":[6,0,0,0,48],
"hangul_8h.html#a0b8d4a416ad7bb42a332332c7ba86da8":[6,0,0,0,62],
"hangul_8h.html#a0c3abd429f2b52cfa38a22ba6a83eb78":[6,0,0,0,54],
"hangul_8h.html#a0f5e452bf9988d2ff966218c115ac8fc":[6,0,0,0,41],
"hangul_8h.html#a125dae990f98e245a98c0df6b158ce69":[6,0,0,0,13],
"hangul_8h.html#a12a0a69a62e5beb75f723a0e35bb2b37":[6,0,0,0,57],
"hangul_8h.html#a136faa4688a685967fd5d7924a0d1881":[6,0,0,0,7],
"hangul_8h.html#a15a192336db645af3e42a330bc5758c8":[6,0,0,0,21],
"hangul_8h.html#a1b60e6f04df1309e5ce72473acc4a634":[6,0,0,0,11],
"hangul_8h.html#a204baf063de1c6418bcf31a3834fe16a":[6,0,0,0,27],
"hangul_8h.html#a22bcb32ef304949469d73470b0211262":[6,0,0,0,17],
"hangul_8h.html#a2603eab2f2cae3b60e0f8a76424be923":[6,0,0,0,28],
"hangul_8h.html#a2f88bf9b2f6d754350f996933a0a9a65":[6,0,0,0,52],
"hangul_8h.html#a34891979cee58130127abd5e461f5d33":[6,0,0,0,29],
"hangul_8h.html#a38561903839667a7ce2fabdcd2b8f6cb":[6,0,0,0,34],
"hangul_8h.html#a39acdbbb3d3177f30f74e4301537a890":[6,0,0,0,10],
"hangul_8h.html#a3e937c42922f7601edb17b747602c471":[6,0,0,0,33],
"hangul_8h.html#a4153618c22f94f11eeb75834a5c0729d":[6,0,0,0,3],
"hangul_8h.html#a4ae3ff116c8cc9e1919f8cbdb82a9f71":[6,0,0,0,5],
"hangul_8h.html#a50a8e6626a7e76210784a560e8ac15b5":[6,0,0,0,51],
"hangul_8h.html#a55301ca3af5a8fbb59185d6d6bd8bf28":[6,0,0,0,37],
"hangul_8h.html#a5683e04e68511d40e66dc8fe26a9a934":[6,0,0,0,49],
"hangul_8h.html#a5c0a9fd787bd30260ef97abe55e295dc":[6,0,0,0,14],
"hangul_8h.html#a5c2ef68c3129eab97f29ac76d6061d9e":[6,0,0,0,22],
"hangul_8h.html#a616c08a55df29fe0956c66c15705bc5f":[6,0,0,0,6],
"hangul_8h.html#a69c78468e5e1edc85cf662efd720a416":[6,0,0,0,16],
"hangul_8h.html#a70c32b954a83568a41bd21f9a7edee2f":[6,0,0,0,24],
"hangul_8h.html#a75ce785d49a097dbbe179d8ebe671c5f":[6,0,0,0,2],
"hangul_8h.html#a7a37b9570683b2dda6c47e093ab30467":[6,0,0,0,45],
"hangul_8h.html#a7b8f3653d0dd30a1145be38529370def":[6,0,0,0,56],
"hangul_8h.html#a7b9e6e3fe44ad89262cbe2cfc41e4fc4":[6,0,0,0,9],
"hangul_8h.html#a80320921dd37bec6024eaf5823df673b":[6,0,0,0,40],
"hangul_8h.html#a84565f505a6cf9584179d595c1dbd331":[6,0,0,0,31],
"hangul_8h.html#a8bcda08741a11636e3236f3d34372bcf":[6,0,0,0,32],
"hangul_8h.html#a90cf07ba103b44a6874cef85de7003a7":[6,0,0,0,20],
"hangul_8h.html#a90cff8fc50796395eeae423b2066c9f9":[6,0,0,0,38],
"hangul_8h.html#a94b0cfe610ce21659026297a9c31d467":[6,0,0,0,0],
"hangul_8h.html#a9aacff561033067830249796de592258":[6,0,0,0,47],
"hangul_8h.html#a9c3b54cce3c1e62a8b4af4c670891431":[6,0,0,0,44],
"hangul_8h.html#a9e675720a862703770bfeb5e4b654493":[6,0,0,0,36],
"hangul_8h.html#aa4bc76a25d376acd2c97455e476ceb42":[6,0,0,0,42],
"hangul_8h.html#aaf73601bfe34292aa58b0d827feb01d8":[6,0,0,0,58],
"hangul_8h.html#ab1bb63330600aa31b5fba9ac58ce171e":[6,0,0,0,4],
"hangul_8h.html#ab5b015eab3736a3f68ccf2a4cfa37805":[6,0,0,0,1],
"hangul_8h.html#ab795ff183c3e429e0eb9257a7737c57f":[6,0,0,0,46],
"hangul_8h.html#aba5138f283da08eb4b9bd56e2fd56cb9":[6,0,0,0,25],
"hangul_8h.html#abaed5273181b15b047e92b3b79f68a4d":[6,0,0,0,59],
"hangul_8h.html#abb373afe914554ff8443f05d83b69e8e":[6,0,0,0,55],
"hangul_8h.html#abb89d6f87b724e1eaea6226484e5e3ad":[6,0,0,0,12],
"hangul_8h.html#abc5d018ac60a7dff7dd90ed98a738089":[6,0,0,0,18],
"hangul_8h.html#ac0722300c0f6653ca96694d023d6c91b":[6,0,0,0,43],
"hangul_8h.html#ac5e9b3d850d9664e702e8cd330cbfa4b":[6,0,0,0,30],
"hangul_8h.html#ad4e7a6ac8160c8f5576487db53d67925":[6,0,0,0,19],
"hangul_8h.html#ae1787a61039977179f60e6f2cda16ac9":[6,0,0,0,50],
"hangul_8h.html#aea2d861820cf998c2fd9eded2fd4d845":[6,0,0,0,15],
"hangul_8h.html#afd372e1a400e28d1b61410187f038eec":[6,0,0,0,53],
"hangul_8h.html#afe4411910308475bdd7e13687987cfc5":[6,0,0,0,26],
"hangul_8h_source.html":[6,0,0,0],
"hex2otf_8c.html":[6,0,0,1],
"hex2otf_8c.html#a01d5b7bf9004b7a8c920f958861d2a8e":[6,0,0,1,22],
"hex2otf_8c.html#a049e485562f7f4dfe978c4146ad225b8":[6,0,0,1,70],
"hex2otf_8c.html#a051a88b0ac4eb063945b84e2242408ea":[6,0,0,1,45],
"hex2otf_8c.html#a0524ff7f6df40782a03af6d8efd1cf45":[6,0,0,1,84],
"hex2otf_8c.html#a06a292e7a76c13c1fa509187a7e6577a":[6,0,0,1,18],
"hex2otf_8c.html#a06b8121dea15c8117b7c951ffb22fb7e":[6,0,0,1,56],
"hex2otf_8c.html#a074562f0527ff6db8b1b956b9356a315":[6,0,0,1,81],
"hex2otf_8c.html#a07b29528c561e5852a228c98391225f7":[6,0,0,1,44],
"hex2otf_8c.html#a07c4a43c1a36ee79c8a163298ff9adac":[6,0,0,1,29],
"hex2otf_8c.html#a0c8186d9b9b7880309c27230bbb5e69d":[6,0,0,1,26],
"hex2otf_8c.html#a0d187cc87528ef35478afd7a68309f08":[6,0,0,1,38],
"hex2otf_8c.html#a0d4560c5d562d31a33f092bb579f8397":[6,0,0,1,47],
"hex2otf_8c.html#a0ddc03905c4918e04aa1e54a7c1716b1":[6,0,0,1,63],
"hex2otf_8c.html#a0ddf1224851353fc92bfbff6f499fa97":[6,0,0,1,67],
"hex2otf_8c.html#a0e5f5e7d04aec261ae28e2fca801194c":[6,0,0,1,10],
"hex2otf_8c.html#a11ea3753e3a4f90123b78a4b1f731bd4":[6,0,0,1,86],
"hex2otf_8c.html#a15c6f2a017088c5db6daac264f992a67":[6,0,0,1,7],
"hex2otf_8c.html#a199befd98ef9ec0ee659d82609abded4":[6,0,0,1,43],
"hex2otf_8c.html#a1a1d1da8a5f6da54d749399b173c9bfc":[6,0,0,1,17],
"hex2otf_8c.html#a1c6d5de492ac61ad29aec7aa9a436bbf":[6,0,0,1,24],
"hex2otf_8c.html#a1fab24bb2d2b38b68a38ec871afc3f9c":[6,0,0,1,36],
"hex2otf_8c.html#a2177c1b55319bb7fd9015fb8b8629ead":[6,0,0,1,8],
"hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38":[6,0,0,1,33],
"hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38a01f5371958d06ab1411c46f72f049f45":[6,0,0,1,33,1],
"hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38a9e771dc35104ec1246adba881d27e372":[6,0,0,1,33,0],
"hex2otf_8c.html#a28e889c3a36007c2e5d50a498046a6c6":[6,0,0,1,58],
"hex2otf_8c.html#a2f5976201b1e630a94045f04a0348572":[6,0,0,1,50],
"hex2otf_8c.html#a326e4fa86eb32bb18e37eab8f495bd2f":[6,0,0,1,64],
"hex2otf_8c.html#a3d62aa29f94c3fa78ca4438739d64a62":[6,0,0,1,53],
"hex2otf_8c.html#a4ac0c02117b703a71bee3dd34e2eb306":[6,0,0,1,57],
"hex2otf_8c.html#a4cebe6a72365812b5f392f4db9dc5db5":[6,0,0,1,66],
"hex2otf_8c.html#a51be7f69e0f6053772b3ddacf215df84":[6,0,0,1,42],
"hex2otf_8c.html#a560637130747e543118ff304389fd18f":[6,0,0,1,40],
"hex2otf_8c.html#a5af7c9bcfd40e5b11f9d12c40966bb65":[6,0,0,1,37],
"hex2otf_8c.html#a6362601eb41d051a103a1d9edcd4f284":[6,0,0,1,54],
"hex2otf_8c.html#a652fd701381105d0d34ca4084cca413c":[6,0,0,1,13],
"hex2otf_8c.html#a6793c760667fe6bf1481f61567954c12":[6,0,0,1,27],
"hex2otf_8c.html#a688a4772d61221e9378e5003da51265a":[6,0,0,1,16],
"hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8c":[6,0,0,1,34],
"hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8ca0bbdc63e5d0938274b80230bc55d03b8":[6,0,0,1,34,1],
"hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8caf18243d8ef6a7f601ae03a6cffbabadd":[6,0,0,1,34,0],
"hex2otf_8c.html#a6c1e982fdc6c51b9f84051daa2e71936":[6,0,0,1,55],
"hex2otf_8c.html#a6ffce9764ba647abe9b3bee1aaadd3a7":[6,0,0,1,76],
"hex2otf_8c.html#a77e92e56b5af63bc912ed4cbf5f5c585":[6,0,0,1,9],
"hex2otf_8c.html#a77ff68152c5cb38605010bc7621b0722":[6,0,0,1,79],
"hex2otf_8c.html#a79d8a322be9d9131b684a9ea67abe05e":[6,0,0,1,61],
"hex2otf_8c.html#a79e768c38f3b21419f01d2d1347523be":[6,0,0,1,20],
"hex2otf_8c.html#a7ccab01e56208030185cefdca13e0ac8":[6,0,0,1,23],
"hex2otf_8c.html#a7d0a7ac24105d9c91bce2b5a1e9a1ad3":[6,0,0,1,14],
"hex2otf_8c.html#a7da3527c69a413194afdce359b03e1ea":[6,0,0,1,35],
"hex2otf_8c.html#a7da3527c69a413194afdce359b03e1eaa9c5871c30feb10df049d99bd703dfda4":[6,0,0,1,35,0],
"hex2otf_8c.html#a7da3527c69a413194afdce359b03e1eaad5e47b5a6bbf31be31e9b1328e7beef8":[6,0,0,1,35,1],
"hex2otf_8c.html#a7feadaf37f40473cfc76921f8754c0f7":[6,0,0,1,25],
"hex2otf_8c.html#a83aece82aa1fe815fc24a12be34a24b1":[6,0,0,1,82],
"hex2otf_8c.html#a84d7310553d31f4ec587dc001f472834":[6,0,0,1,46],
"hex2otf_8c.html#a84fd83fab1f19cfb33addaa0557c4682":[6,0,0,1,12],
"hex2otf_8c.html#a8ac383e879c9d7d9af6005444970c837":[6,0,0,1,28],
"hex2otf_8c.html#a91005fb187034d042b6bad9c9b1ae7c4":[6,0,0,1,11],
"hex2otf_8c.html#a91d9682686a5100fae5b0cf362940e14":[6,0,0,1,85],
"hex2otf_8c.html#a927c31a7e187d15a70667ce6b0ef296a":[6,0,0,1,41],
"hex2otf_8c.html#a941153850cde042e39ce40d47d5aac5f":[6,0,0,1,83],
"hex2otf_8c.html#a97af00050b8fd6b7e7b81c7027e4c8e6":[6,0,0,1,73],
"hex2otf_8c.html#a97c9b2ae58f5989d68e639715c3f9df9":[6,0,0,1,59],
"hex2otf_8c.html#a97fbabab590ac85657edb01474da7d50":[6,0,0,1,30],
"hex2otf_8c.html#aa52cd46a50cdc2040a72e5c7ecfa944b":[6,0,0,1,74],
"hex2otf_8c.html#aaa5713bb2ecdf81c430009179b806232":[6,0,0,1,32],
"hex2otf_8c.html#ab37b4f7111692f8d1163bafd2aab831e":[6,0,0,1,52],
"hex2otf_8c.html#ab6e3bb110dc3e55193c344cb7b56e328":[6,0,0,1,62],
"hex2otf_8c.html#ab9f46992237e1552d3ae221b2a5e95ff":[6,0,0,1,31],
"hex2otf_8c.html#abce67139ad0bc979ef080a694e60fb36":[6,0,0,1,21],
"hex2otf_8c.html#ac2eec01939cae967aa9882b2517288a1":[6,0,0,1,71],
"hex2otf_8c.html#ac928f7761fc187ff86f33805309bec21":[6,0,0,1,65],
"hex2otf_8c.html#acfd4c464cd710f2311581f0002c06020":[6,0,0,1,48],
"hex2otf_8c.html#ad0d9350c8943e5550a14f1cff5580a6c":[6,0,0,1,6],
"hex2otf_8c.html#ad0f95bf4a3a4a28b173b971e246b8745":[6,0,0,1,15],
"hex2otf_8c.html#ad77c441582f862d494a734eb9855dd41":[6,0,0,1,78],
"hex2otf_8c.html#ae19e0a10c9b6b5aaf1878cac27ea9541":[6,0,0,1,75],
"hex2otf_8c.html#ae28f2f636e4d3dd3b5784a3bc3f92b58":[6,0,0,1,77],
"hex2otf_8c.html#ae2b46edf2ac290c695e2b27d16f1b380":[6,0,0,1,80],
"hex2otf_8c.html#ae32c0f82cbb6a4d8ece0559f1c7b74f4":[6,0,0,1,49],
"hex2otf_8c.html#ae8310060f5a9b7cefb84d0bb1b459b64":[6,0,0,1,69],
"hex2otf_8c.html#af1223f39e8627e0a3b0b7b533e6d0b64":[6,0,0,1,39],
"hex2otf_8c.html#af1d113ec0d790035476f2743cbf2696f":[6,0,0,1,68],
"hex2otf_8c.html#af25acbe53b9070c1400a04c9231691bb":[6,0,0,1,19],
"hex2otf_8c.html#af3ba1ba33ebe63ba0340842b7f83021c":[6,0,0,1,72],
"hex2otf_8c.html#afd499a24ff34cb5c19b52df795422c12":[6,0,0,1,51],
"hex2otf_8c.html#aff4f28ce178c84c7365245ec10034433":[6,0,0,1,60],
"hex2otf_8c_source.html":[6,0,0,1],
"hex2otf_8h.html":[6,0,0,2],
"hex2otf_8h.html#a02993e3b8886c3fc79e0a862582e5fd3":[6,0,0,2,6],
"hex2otf_8h.html#a3a8d3619901c1776556d259d0295c6ef":[6,0,0,2,5],
"hex2otf_8h.html#a59ba14cafe02ba112aa260cb17affc45":[6,0,0,2,1],
"hex2otf_8h.html#a62e32863ba84411a48a0049151e68a00":[6,0,0,2,9],
"hex2otf_8h.html#a7932112a8cd522740aa941c15b79bd16":[6,0,0,2,11],
"hex2otf_8h.html#a80457952fba9de3914d0f44305236ef2":[6,0,0,2,2],
"hex2otf_8h.html#a91c55841985cdffac3f8d7d6252749dc":[6,0,0,2,4],
"hex2otf_8h.html#aafa9d4317a3af734d88d6b977de27de9":[6,0,0,2,8],
"hex2otf_8h.html#adb78d0325526094d79149d20028f82d0":[6,0,0,2,7],
"hex2otf_8h.html#af3ad95ac6274edc8333dcbd3706aa603":[6,0,0,2,3],
"hex2otf_8h.html#af57a7327559d80dc41d283c61c6e7063":[6,0,0,2,10],
"hex2otf_8h_source.html":[6,0,0,2],
"index.html":[],
"index.html#Introduction":[2],
"index.html#License":[1],
"index.html#Programs":[3],
"index.html#Scripts":[4],
"index.html#Title":[0],
"johab2syllables_8c.html":[6,0,0,3],
"johab2syllables_8c.html#a0ddf1224851353fc92bfbff6f499fa97":[6,0,0,3,0],
"johab2syllables_8c.html#a402ea961bfc2ffeee61e3a7c330b1559":[6,0,0,3,1],
"johab2syllables_8c_source.html":[6,0,0,3],
"pages.html":[],
"structBuffer.html":[5,0,0],
"structFont.html":[5,0,1],
"structGlyph.html":[5,0,2],
"structGlyph.html#a08ed20f3df1902ce776f6e1fccd089b9":[5,0,2,2],
"structGlyph.html#a7fb4dc03b71777de880164eee4ffbc51":[5,0,2,4],
"structGlyph.html#aa309ceb984d5524ef7dab0e8927fdd64":[5,0,2,1],
"structGlyph.html#abbbc1113c6e10dc0fa986abbb7f7665e":[5,0,2,0],
"structGlyph.html#ac113da35f4193641855eaf51547f9b43":[5,0,2,5],
"structGlyph.html#ada6b8b4b9419096c413b5a29dbc54aac":[5,0,2,3],
"structNamePair.html":[5,0,3],
"structOptions.html":[5,0,4],
"structPARAMS.html":[5,0,5],
"structTable.html":[5,0,6],
"structTableRecord.html":[5,0,7],
"unibdf2hex_8c.html":[6,0,0,4],
"unibdf2hex_8c.html#a2e467ad6d1fb7b24985a45af8b1e7ad1":[6,0,0,4,1],
"unibdf2hex_8c.html#a840291bc02cba5474a4cb46a9b9566fe":[6,0,0,4,3],
"unibdf2hex_8c.html#ad7871643c05865c80f5d8050aead2b57":[6,0,0,4,0],
"unibdf2hex_8c.html#afd5dcd82c8e611d544ad18b798c54d50":[6,0,0,4,2],
"unibdf2hex_8c_source.html":[6,0,0,4],
"unibmp2hex_8c.html":[6,0,0,5],
"unibmp2hex_8c.html#a0ddf1224851353fc92bfbff6f499fa97":[6,0,0,5,1],
"unibmp2hex_8c.html#a23c536e061c3387fee66c7f6250f2b58":[6,0,0,5,7],
"unibmp2hex_8c.html#a4000465b001e714b0bfa857e4956a76c":[6,0,0,5,8],
"unibmp2hex_8c.html#a6ab9015718d2f37f1420e7a0b53713ec":[6,0,0,5,9],
"unibmp2hex_8c.html#a77fe45bfa888a90761ae6dc8627fdd5e":[6,0,0,5,5],
"unibmp2hex_8c.html#a8b1d9ca32eaf9f66c2a2d2d7761b8526":[6,0,0,5,2],
"unibmp2hex_8c.html#a8e50648544568f9274781c2c90acdd78":[6,0,0,5,6],
"unibmp2hex_8c.html#aa2196ad512cd5cffe3c54f7798f1b286":[6,0,0,5,3],
"unibmp2hex_8c.html#ad7871643c05865c80f5d8050aead2b57":[6,0,0,5,0],
"unibmp2hex_8c.html#af7ab3cd5a9f70af7701580cdf283636c":[6,0,0,5,4],
"unibmp2hex_8c_source.html":[6,0,0,5],
"unibmpbump_8c.html":[6,0,0,6],
"unibmpbump_8c.html#a0ddf1224851353fc92bfbff6f499fa97":[6,0,0,6,3],
"unibmpbump_8c.html#a1c6d5de492ac61ad29aec7aa9a436bbf":[6,0,0,6,1],
"unibmpbump_8c.html#a58f734bf43b58f0f2c28fd4a0582c0f4":[6,0,0,6,4],
"unibmpbump_8c.html#aadfd205e5b62832a2ef6266260cb55f1":[6,0,0,6,0]
};
